<html>
<head>
<title>Listing 24-8</title>
</head>
<body>
<?php
	/*
	** Function: verifyEmail
	** Input: STRING address, REFERENCE error
	** Output: BOOLEAN
	** Description: Attempts to verify an email address by
	** contacting a mail exchanger. Registered mail
	** exchangers are requested from the domain controller first,
	** then the exact domain itself. The error argument will
	** contain relevant text if the address could not be
	** verified.
	*/
	function verifyEmail($address, &$error)
	{
		$mxhost = array();
		$mxweight = array();
		list($user, $domain) = split("@", $address, 2);

		//make sure the domain has a mail exchanger
		if(dns_check_record($domain, "MX"))
		{
			//get mail exchanger records
			if(!dns_get_mx($domain, $mxhost, $mxweight))
			{
				$error = "Could not retrieve mail exchangers!<br>\n";
				return(FALSE);
			}
		}
		else
		{
			//if no mail exchanger, maybe the host itself
			//will accept mail
			$mxhost[] = $domain;
			$mxweight[] = 1;
		}

		//create sorted array of hosts
		$weighted_host = array();
		for($i = 0; $i < count($mxhost); $i++)
		{
			$weighted_host[($mxweight[$i])] = $mxhost[$i];
		}
		ksort($weighted_host);

		//loop over each host
		foreach($weighted_host as $host)
		{
			//connect to host on SMTP port
			if(!($fp = fsockopen($host, 25)))
			{
				//couldn't connect to this host, but
				//the next might work
				continue;
			}

			/*
			** skip over "220" messages
			** give up if no response for 10 seconds
			*/
			stream_set_blocking($fp, FALSE);
			$stopTime = time() + 10;
			$gotResponse = FALSE;
			while(TRUE)
			{
				//try to get a line from mail server
				$line = fgets($fp, 1024);
				if(substr($line, 0, 3) == "220")
				{
					//reset timer
					$stopTime = time() + 10;
					$gotResponse = TRUE;
				}
				elseif(($line == "") AND ($gotResponse))
				{
					break;
				}
				elseif(time() > $stopTime)
				{
					break;
				}
			}

			if(!$gotResponse)
			{
				//this host was unresponsive, but
				//maybe the next will be better
				continue;
			}
	
			stream_set_blocking($fp, TRUE);
	
			//sign in
			fputs($fp, "HELO {$_SERVER['SERVER_NAME']}\r\n");
			fgets($fp, 1024);
	
			//set from
			fputs($fp, "MAIL FROM: " .
				"<httpd@{$_SERVER['SERVER_NAME']}>\r\n");
				fgets($fp, 1024);
	
			//try address
			fputs($fp, "RCPT TO: <$address>\r\n");
			$line = fgets($fp, 1024);
	
			//close connection
			fputs($fp, "QUIT\r\n");
			fclose($fp);
			if(substr($line, 0, 3) != "250")
			{
				//mail server doesn't recognize
				//this address, so it must be bad
				$error = $line;
				return(FALSE);
			}
			else
			{
				//address recognized
				return(TRUE);
			}
		}

		$error = "Unable to reach a mail exchanger!";
		return(FALSE);
	}

	if(verifyEmail("leon@clearink.com", $error))
	{
		print("Verified!<br>\n");
	}
	else
	{
		print("Could not verify!<br>\n");
		print("Error: $error<br>\n");
	}
?>
</body>
</html>