<?php
	/*
	** PNG button
	** Creates a graphical button based
	** on form variables.
	*/
	class Button
	{
		private $image;

		public function __construct($width, $height, $label, $font)
		{
			$this->image = imagecreate($width, $height);
			$colorBody = imagecolorallocate($this->image,
				0x99, 0x99, 0x99);
			$colorShadow = imagecolorallocate($this->image,
				0x33, 0x33, 0x33);
			$colorHighlight = imagecolorallocate($this->image,
				0xCC, 0xCC, 0xCC);

			//create body of button
			imagefilledrectangle($this->image,
				1, 1, $width-2, $height-2,
				$colorBody);
	
			//draw bottom shadow
			imageline($this->image,
				0, $height-1,
				$width-1, $height-1,
				$colorShadow);

			//draw right shadow
			imageline($this->image,
				$width-1, 1,
				$width-1, $height-1,
				$colorShadow);

			//draw top highlight
			imageline($this->image,
				0, 0,
				$width-1, 0,
				$colorHighlight);

			//draw left highlight
			imageline($this->image,
				0, 0,
				0, $height-2,
				$colorHighlight);

			//determine label size
			$labelHeight = imagefontheight($font);
			$labelWidth = imagefontwidth($font) * strlen($label);

			//determine label upper left corner
			$labelX = ($width - $labelWidth)/2;
			$labelY = ($height - $labelHeight)/2;

			//draw label shadow
			imagestring($this->image,
				$font,
				$labelX+1,
				$labelY+1,
				$label,
				$colorShadow);

			//draw label
			imagestring($this->image,
				$font,
				$labelX,
				$labelY,
				$label,
				$colorHighlight);
		}

		public function drawPNG()
		{
			header("Content-type: image/png");
			imagepng($this->image);
		}

		public function drawJPEG()
		{
			header("Content-type: image/jpeg");
			imagejpeg($this->image);
		}
	}

	//set parameters if not given
	if(!isset($_REQUEST['width']))
	{
		$_REQUEST['width'] = 100;
	}

	if(!isset($_REQUEST['height']))
	{
		$_REQUEST['height'] = 30;
	}

	if(!isset($_REQUEST['label']))
	{
		$_REQUEST['label'] = "CLICK";
	}

	if(!isset($_REQUEST['font']))
	{
		$_REQUEST['font'] = 5;
	}

	$b = new Button($_REQUEST['width'], $_REQUEST['height'],
		$_REQUEST['label'], $_REQUEST['font']);
	$b->drawPNG();
?>