<?php
	/*
	** Configuration file singleton
	*/
	class Configuration
	{
		static private $instance = NULL;
		private $ini_settings;
		private $updated = FALSE;
		const INI_FILENAME = "/tmp/corephp.ini";

		private function __construct()
		{
			if(file_exists(self::INI_FILENAME))
			{
				$this->ini_settings =
					parse_ini_file(self::INI_FILENAME);
			}
		}

		private function __destruct()
		{
			//if configuration hasn't changed, no need
			//to update it on disk
			if(!$this->updated)
			{
				return;
			}
	
			//overwrite INI file with the
			//version in memory
			$fp = fopen(self::INI_FILENAME, "w");
			if(!$fp)
			{
				return;
			}

			foreach ($this->ini_settings as $key => $value)
			{
				fputs($fp, "$key = \"$value\"\n");
			}

			fclose($fp);
		}

		public function getInstance()
		{
			if(self::$instance == NULL)
			{
				self::$instance = new Configuration();
			}
	
			return self::$instance;
		}

		public function get($name)
		{
			if(isset($this->ini_settings[$name]))
			{
				return $this->ini_settings[$name];
			}
			else
			{
				return(NULL);
			}
		}

		public function set($name, $value)
		{
			//update only if different from what
			//we already have
			if(!isset($this->ini_settings[$name]) OR
				($this->ini_settings[$name] != $value))
			{
				$this->ini_settings[$name] = $value;
				$this->updated = TRUE;
			}
		}
	}

	//Test the class
	$config = Configuration::getInstance();
	$config->set("username", "leon");
	$config->set("password", "secret");
	print($config->get("username"));
?>