<?php
	interface Message
	{
		static function getType();
	};

	interface Observer
	{
		function notifyMsg(Message $msg);
	};

	class Subject
	{
		private $observers = array();

		function registerObserver(Observer $observer, $msgType)
		{
			$this->observers[$msgType][] = $observer;
		}

		private function notifyMsg(Message $msg)
		{
			@$observers = $this->observers[$msg->getType()];

			if(!$observers)
			{
				return;
			}

			foreach($observers as $observer)
			{
				$observer->notifyMsg($msg);
			}
		}

		function someMethod()
		{
			//fake some task
			sleep(1);

			//notify observers
			$this->notifyMsg(new HelloMessage("Zeev"));
		}
	}

	class HelloMessage implements Message
	{
		private $name;

		function __construct($name)
		{
			$this->name = $name;
		}

		function getMsg()
		{
			return "Hello, $this->name!";
		}

		static function getType()
		{
			return "HELLO_TYPE";
		}
	}

	class MyObserver implements Observer
	{
		function notifyMsg(Message $msg)
		{
			if ($msg instanceof HelloMessage)
			{
				print $msg->getMsg();
			}
		}
	}

	$subject = new Subject();
	$observer = new MyObserver();
	$subject->registerObserver($observer,
	HelloMessage::getType());
	$subject->someMethod();
?>